<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=fa
// ** ne pas modifier le fichier **

return [

	// M
	'mediabox_nom' => 'مدياباكس',
	'mediabox_slogan' => 'صندوق چندرسانه‌اي',
];
